Service class

Wrapper to interact with ROS services.

Constructors

Service({required Ros ros, required String name, required String type})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAdvertised → bool
Checks whether or not the service is currently advertising.
no setter
listener ↔ StreamSubscription?
getter/setter pair
name ↔ String
Name of the service.
getter/setter pair
ros ↔ Ros
The ROS connection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
Type of the service.
getter/setter pair

Methods

call(dynamic req) → Future
Call the service with a request (req).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
unadvertise() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited